## Summary of datastructures

TODO: reduce duplication

points
 - class StraightSegment
   - class Type (H, V, S)

tracks
 - class Track
   - direction (X, Y)
 - class Tracks

in channel
 - class _Track
   - class Type (X, Y)
 - class Track
 - class Direction (INC, DEC, BI)

in channel2
 - track is implicit tuple (min, max, idx)
